---
name: Feature
about: Feature template
title: ''
labels: ''
assignees: ''

---

**Use cases, pain points, and background**
Why should we do this? Why is this needed or wanted?

**Description**:
What should we do?

**Design**:
What files should be touched? What logic should be written?

**Out of scope**:
What are some items that this issue could be mistaken to cover that this issue should explicitly NOT cover?

**Acceptance Criteria**:
- [ ] Individual items that need to be finished in order for this issue to be considered completed
